@@ -5,7 +5,7 @@ use Data::Printer::Object;
 use Data::Printer::Common;
 use Data::Printer::Config;
 
-our $VERSION = '1.001000';
+our $VERSION = '1.001001';
 $VERSION = eval $VERSION;
 
 my $rc_arguments;
@@ -112,9 +112,20 @@ sub p (\[@$%&];%) {
 
     my $caller = caller;
     my $args_to_use = _fetch_args_with($caller, \%properties);
-    return if $args_to_use->{quiet};
-    my $printer = Data::Printer::Object->new($args_to_use);
     my $want_value = defined wantarray;
+
+    # return as quickly as possible under 'quiet'.
+    if ($args_to_use->{quiet}) {
+        # we avoid creating a Data::Printer::Object instance
+        # to speed things up, since we don't do anything under 'quiet'.
+        my $return_type = Data::Printer::Common::_fetch_anyof(
+            $args_to_use, 'return_value', 'pass', [qw(pass dump void)]
+        );
+        return _handle_output(undef, undef, $want_value, $_[0], $return_type, 1);
+    }
+
+    my $printer = Data::Printer::Object->new($args_to_use);
+
     if ($printer->colored eq 'auto' && $printer->return_value eq 'dump' && $want_value) {
         $printer->{_output_color_level} = 0;
     }
@@ -131,7 +142,7 @@ sub p (\[@$%&];%) {
         $output = $printer->_write_label . $output;
     }
 
-    return _handle_output($printer, $output, $want_value, $_[0]);
+    return _handle_output($output, $printer->{output_handle}, $want_value, $_[0], $printer->return_value, undef);
 }
 
 # This is a p() clone without prototypes. Just like regular Data::Dumper,
@@ -151,10 +162,20 @@ sub _p_without_prototypes  {
 
     my $caller = caller;
     my $args_to_use = _fetch_args_with($caller, \%properties);
-    return if $args_to_use->{quiet};
+    my $want_value = defined wantarray;
+
+    # return as quickly as possible under 'quiet'.
+    if ($args_to_use->{quiet}) {
+        # we avoid creating a Data::Printer::Object instance
+        # to speed things up, since we don't do anything under 'quiet'.
+        my $return_type = Data::Printer::Common::_fetch_anyof(
+            $args_to_use, 'return_value', 'pass', [qw(pass dump void)]
+        );
+        return _handle_output(undef, undef, $want_value, $_[0], $return_type, 1);
+    }
+
     my $printer = Data::Printer::Object->new($args_to_use);
 
-    my $want_value = defined wantarray;
     if ($printer->colored eq 'auto' && $printer->return_value eq 'dump' && $want_value) {
         $printer->{_output_color_level} = 0;
     }
@@ -172,15 +193,15 @@ sub _p_without_prototypes  {
         $output = $printer->_write_label . $output;
     }
 
-    return _handle_output($printer, $output, $want_value, $_[0]);
+    return _handle_output($output, $printer->{output_handle}, $want_value, $_[0], $printer->return_value, undef);
 }
 
 
 sub _handle_output {
-    my ($printer, $output, $wantarray, $data) = @_;
+    my ($output, $out_handle, $wantarray, $data, $return_type, $quiet) = @_;
 
-    if ($printer->return_value eq 'pass') {
-        print { $printer->{output_handle} } $output . "\n";
+    if ($return_type eq 'pass') {
+        print { $out_handle } $output . "\n" unless $quiet;
         require Scalar::Util;
         my $ref = Scalar::Util::blessed($data);
         return $data if defined $ref;
@@ -201,8 +222,8 @@ sub _handle_output {
             return $data;
         }
     }
-    elsif ($printer->return_value eq 'void' || !$wantarray) {
-        print { $printer->{output_handle} } $output . "\n";
+    elsif ($return_type eq 'void' || !$wantarray) {
+        print { $out_handle} $output . "\n" unless $quiet;
         return;
     }
     else {
@@ -327,7 +348,7 @@ Here's what Data::Printer offers Perl developers, out of the box:
 
 =over 4
 
-=item * Variable dumps designed for I<< easy parsing by the human brain >>,
+=item * Variable dumps designed for B<< easy parsing by the human brain >>,
 not a machine.
 
 =back
@@ -371,11 +392,18 @@ or install hardcore tools like Devel::Peek and Devel::Gladiator.
 
 =over 4
 
+=item * B<< Full support for dumping perl 5.38 native classes >>.
+
+=back
+
+=over 4
+
 =item * keep your custom settings on a
 L<< .dataprinter|/The .dataprinter configuration file >> file that allows
-B<< different options per module >> being analyzed! You may also create a
-custom L<profile|Data::Printer::Profile> class with your preferences and
-filters and upload it to CPAN.
+B<< different options per module >> being analyzed! You can have
+B<< one C<.dataprinter> file per project >>, or default to one in your home
+directory. You may also create a custom L<profile|Data::Printer::Profile> class
+with your preferences and filters and upload it to CPAN.
 
 =back
 
@@ -399,7 +427,8 @@ and the customization section below cover about 90% of all use cases.
 =over 4
 
 =item * Works on B<< Perl 5.8 and later >>. Because you can't control where
-you debug, we try our best to be compatible with all versions of Perl 5.
+you debug, we try our best to be compatible with all versions of Perl 5, from
+the oldest available to the bleeding edge.
 
 =back
 
@@ -932,8 +961,24 @@ to be dumped using Data::Printer.
 =head2 Using Data::Printer in a perl shell (REPL)
 
 Some people really enjoy using a REPL shell to quickly try Perl code. One
-of the most popular ones out there is L<Devel::REPL>. If you use it, now
-you can also see its output with Data::Printer!
+of the most popular ones out there are L<Reply> and L<Devel::REPL>. If you
+use them, now you can also see its output with Data::Printer!
+
+=over 4
+
+=item * B<Reply>
+
+=back
+
+Just install L<Reply::Plugin::DataPrinter> and add a line with
+C<< [DataPrinter] >> to your C<.replyrc> file. That's it! Next time
+you run the 'reply' REPL, Data::Printer will be used to dump variables!
+
+=over 4
+
+=item * B<Devel::REPL>
+
+=back
 
 Just install L<Devel::REPL::Plugin::DataPrinter> and add the following
 line to your re.pl configuration file (usually ".re.pl/repl.rc" in your
@@ -1061,22 +1106,22 @@ Chad Granum (exodist), Chris Prather (perigrin), Curtis Poe (Ovid),
 David D Lowe (Flimm), David E. Condon (hhg7), David Golden (xdg),
 David Precious (bigpresh), David Raab, David E. Wheeler (theory),
 Damien Krotkine (dams), Denis Howe, dirk, Dotan Dimet, Eden Cardim (edenc),
-Elliot Shank (elliotjs), Eugen Konkov (KES777), Fernando Corrêa (SmokeMachine),
-Fitz Elliott, Florian (fschlich), Frew Schmidt (frew), GianniGi,
-Graham Knop (haarg), Graham Todd, Gregory J. Oschwald, grr, Håkon Hægland,
-Iaroslav O. Kosmina (darviarush), Ivan Bessarabov (bessarabv), J Mash,
-James E. Keenan (jkeenan), Jarrod Funnell (Timbus), Jay Allen (jayallen),
-Jay Hannah (jhannah), jcop, Jesse Luehrs (doy), Joel Berger (jberger),
-John S. Anderson (genehack), Karen Etheridge (ether),
-Kartik Thakore (kthakore), Kevin Dawson (bowtie), Kevin McGrath (catlgrep),
-Kip Hampton (ubu), Londran, Marcel Grünauer (hanekomu),
-Marco Masetti (grubert65), Mark Fowler (Trelane), Martin J. Evans,
-Matt S. Trout (mst), Maxim Vuets, Michael Conrad, Mike Doherty (doherty),
-Nicolas R (atoomic),  Nigel Metheringham (nigelm), Nuba Princigalli (nuba),
-Olaf Alders (oalders), Paul Evans (LeoNerd), Pedro Melo (melo),
-Philippe Bruhat (BooK), Przemysław Wesołek (jest), Rebecca Turner (iarna),
-Renato Cron (renatoCRON), Ricardo Signes (rjbs), Rob Hoelz (hoelzro),
-Salve J. Nilsen (sjn), sawyer, Sebastian Willing (Sewi),
+Elliot Shank (elliotjs), Elvin Aslanov, Eugen Konkov (KES777),
+Fernando Corrêa (SmokeMachine), Fitz Elliott, Florian (fschlich),
+Frew Schmidt (frew), GianniGi, Graham Knop (haarg), Graham Todd,
+Gregory J. Oschwald, grr, Håkon Hægland, Iaroslav O. Kosmina (darviarush),
+Ivan Bessarabov (bessarabv), J Mash, James E. Keenan (jkeenan),
+Jarrod Funnell (Timbus), Jay Allen (jayallen), Jay Hannah (jhannah), jcop,
+Jesse Luehrs (doy), Joel Berger (jberger), John S. Anderson (genehack),
+Karen Etheridge (ether), Kartik Thakore (kthakore), Kevin Dawson (bowtie),
+Kevin McGrath (catlgrep), Kip Hampton (ubu), Londran,
+Marcel Grünauer (hanekomu), Marco Masetti (grubert65), Mark Fowler (Trelane),
+Martin J. Evans, Matthias Muth, Matt S. Trout (mst), Maxim Vuets, Michael Conrad,
+Mike Doherty (doherty), Nicolas R (atoomic), Nigel Metheringham (nigelm),
+Nuba Princigalli (nuba), Olaf Alders (oalders), Paul Evans (LeoNerd),
+Pedro Melo (melo), Philippe Bruhat (BooK), Przemysław Wesołek (jest),
+Rebecca Turner (iarna), Renato Cron (renatoCRON), Ricardo Signes (rjbs),
+Rob Hoelz (hoelzro), Salve J. Nilsen (sjn), sawyer, Sebastian Willing (Sewi),
 Sébastien Feugère (smonff), Sergey Aleynikov (randir), Slaven Rezić,
 Stanislaw Pusep (syp), Stephen Thirlwall (sdt), sugyan, Tai Paul,
 Tatsuhiko Miyagawa (miyagawa), Thomas Sibley (tsibley),
@@ -1089,7 +1134,7 @@ If I missed your name, please drop me a line!
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2011-2021 Breno G. de Oliveira
+Copyright (C) 2011-2023 Breno G. de Oliveira
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
