@@ -3,7 +3,10 @@ use strict;
 use warnings;
 use Data::Printer::Filter;
 
-filter 'FORMAT' => sub {
+filter 'FORMAT' => \&parse;
+
+
+sub parse {
     my ($format, $ddp) = @_;
     return $ddp->maybe_colorize('FORMAT', 'format');
 };
